#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/* keep track of the 4 registers */
typedef struct {
    int a, b, c, d;
} Tr4k;

/* returns a pointer to the int in a Tr4k for whatever letter we are using */
int* reg(Tr4k* trak, const char* name) {
    if (!strcmp(name, "A")) return &trak->a;
    if (!strcmp(name, "B")) return &trak->b;
    if (!strcmp(name, "C")) return &trak->c;
    if (!strcmp(name, "D")) return &trak->d;
    return NULL;
}

/* simulate one instruction in the control program
 * this adds to the fifths_of_second parameter as needed
 * it returns next pc, or -1 in case we hit a halt */
int sim(Tr4k* trak, char* orig, int* fifths_of_second, int pc) {
    /* strtok destroys the original string, so make a copy */
    char instruction[500];
    strcpy(instruction, orig);

    /* begin tokenizing things */
    char* token = strtok(instruction, " ");
    int* dest;
    int src1, src2;
    int line;

    /* all the instructions start with a different letter, so we switch on that */
    switch (token[0]) {
        /* set */
        case 's':
            dest = reg(trak, strtok(NULL, " "));
            int value = atoi(strtok(NULL, " "));
            *dest = value;
            return pc + 1;

        /* add */
        case 'a':
            dest = reg(trak, strtok(NULL, " "));
            src1 = *reg(trak, strtok(NULL, " "));
            src2 = *reg(trak, strtok(NULL, " "));
            *dest = src1 + src2;
            return pc + 1;

        /* mul */
        case 'm':
            dest = reg(trak, strtok(NULL, " "));
            src1 = *reg(trak, strtok(NULL, " "));
            src2 = *reg(trak, strtok(NULL, " "));
            *dest = src1 * src2;
            return pc + 1;
            return pc + 1;

        /* turn */
        case 't':
            int angle = *reg(trak, strtok(NULL, " "));
            int seconds = abs(angle / 90);
            *fifths_of_second += seconds * 5;
            return pc + 1;

        /* drive */
        case 'd':
            int feet = *reg(trak, strtok(NULL, " "));
            *fifths_of_second += feet;
            return pc + 1;

        /* jump */
        case 'j':
            line = atoi(strtok(NULL, " "));
            return line;

        /* eqjump */
        case 'e':
            src1 = *reg(trak, strtok(NULL, " "));
            src2 = *reg(trak, strtok(NULL, " "));
            line = atoi(strtok(NULL, " "));
            return (src1 == src2) ? line : pc + 1;

        /* halt */
        case 'h':
            return -1;
    }

    return -1;
}

int main() {
    int n;
    char program[50][1000];
    
    scanf("%d\n", &n);
    for (int i = 0; i < n; i++) {
        scanf("%[^\n]\n", program[i]);
    }

    int pc = 0;
    Tr4k trak;

    /* because it goes 5 ft/second, we store fifths of a second to avoid needing doubles */
    int fifths_of_second = 0;

    /* do all of the instructions until a -1 is given for the next pc */
    while (pc != -1) {
        pc = sim(&trak, program[pc], &fifths_of_second, pc);
    }

    /* the answer is fifths_of_second divide by 5 (truncating) */
    printf("%d\n", fifths_of_second / 5);
    return 0;
}

