#include <stdio.h>
#include <stdlib.h>

/* we can walk on anything except # and X */
int canwalk(char thing) {
    return thing != '#' && thing != 'X';
}

/* give the time taken for a step given the tile we are on, and direction */
double stepCost(char tile, char dir) {
    if (tile == dir) return 0.5;
    else if (tile == '<' && dir == '>' ||
             tile == '>' && dir == '<' ||
             tile == 'v' && dir == '^' ||
             tile == '^' && dir == 'v')
        return 2.0;
    else return 1.0;
}

/* do DFS, but stop if we hit the time limit */
int timedDFS(char** grid, int row, int col, int drow, int dcol, double ticker, double limit) {
    /* check if the bad robots got us on this path :( */
    if (ticker > limit) return 0;

    /* check if we got to the elevator :) */
    if (row == drow && col == dcol) {
        return 1;
    }

    /* save original value here and mark it as seen */
    char orig = grid[row][col];
    grid[row][col] = 'X';

    /* try to go in all four directions
     * we assume walls around edges so no need to bounds check */
    if (canwalk(grid[row - 1][col])) {
        if (timedDFS(grid, row - 1, col, drow, dcol, ticker + stepCost(orig, '^'), limit)) return 1;
    }

    if (canwalk(grid[row + 1][col])) {
        if (timedDFS(grid, row + 1, col, drow, dcol, ticker + stepCost(orig, 'v'), limit)) return 1;
    }

    if (canwalk(grid[row][col - 1])) {
        if (timedDFS(grid, row, col - 1, drow, dcol, ticker + stepCost(orig, '<'), limit)) return 1;
    }

    if (canwalk(grid[row][col + 1])) {
        if (timedDFS(grid, row, col + 1, drow, dcol, ticker + stepCost(orig, '>'), limit)) return 1;
    }

    /* undo the step we took and give up */
    grid[row][col] = orig;
    return 0;
}

/* find the C or E in a grid */
void findChar(char** grid, int width, int height, char target, int* frow, int* fcol) {
    for (int row = 0; row < height; row++) {
        for (int col = 0; col < width; col++) {
            if (grid[row][col] == target) {
                *frow = row;
                *fcol = col;
            }
        }
    }
}

int main() {
    double limit;
    int width, height;
    scanf("%lf\n%d %d\n", &limit, &width, &height);

    /* load in the grid */
    char** grid = malloc(sizeof(char*) * height);
    for (int i = 0; i < height; i++) {
        grid[i] = malloc(sizeof(char) * width);
        scanf("%[^\n]\n", grid[i]);
    }

    /* find start and end locations */
    int crow, ccol, erow, ecol;
    findChar(grid, width, height, 'C', &crow, &ccol);
    findChar(grid, width, height, 'E', &erow, &ecol);

    /* do the timed search */
    if (timedDFS(grid, crow, ccol, erow, ecol, 0.0, limit)) {
        printf("CORA makes it\n");
    } else {
        printf("CORA does not make it\n");
    }

    /* free the grid */
    for (int i = 0; i < height; i++) {
        free(grid[i]);
    }
    free(grid);

    return 0;
}

