#include <stdio.h>
#include <stdlib.h>
#include <string.h>

typedef struct {
    int time;
    int impact;
} Wire;

int max(int a, int b) {
    return a > b ? a : b;
}

/* for memoizing the recursion */
int** past_results;

int max_impact(Wire* wires, int time_left, int num_wires, int i) {
    /* if there are no wires, there's no impact */
    if (num_wires == 0) return 0;

    /* check if we have a cached answer */
    if (past_results[i][time_left] != -1) {
        return past_results[i][time_left];
    }

    /* check if we even can include the next wire */
    if (wires[i].time <= time_left) {
        /* we can either include this wire in the set being cut, or not */
        int impact_with = wires[i].impact + max_impact(wires, time_left - wires[i].time, num_wires - 1, i + 1);
        int impact_without = max_impact(wires, time_left, num_wires - 1, i + 1);
        past_results[i][time_left] = max(impact_with, impact_without);
        return past_results[i][time_left];
    } else {
        /* can't include this one, move on */
        past_results[i][time_left] = max_impact(wires, time_left, num_wires - 1, i + 1);
        return past_results[i][time_left];
    }
}

int main() {
    /* read inputs */
    int T, N;
    scanf("%d %d\n", &T, &N);
    Wire wires[N];
    for (int i = 0; i < N; i++) {
        scanf("%d %d\n", &wires[i].time, &wires[i].impact);
    }

    /* initialize past results */
    past_results = malloc(N * sizeof(int*));
    for (int i = 0; i < N; i++) {
        past_results[i] = malloc((T + 1) * sizeof(int));
        for (int j = 0; j <= T; j++) {
            past_results[i][j] = -1;
        }
    }

    /* do the thing */
    int impact = max_impact(wires, T, N, 0);
    printf("%d\n", impact);

    /* free memoization array */
    for (int i = 0; i < N; i++) {
        free(past_results[i]);
    }
    free(past_results);


    return 0;
}

